@@ -1,8 +1,8 @@
 {-# LANGUAGE MultiWayIf #-}
 
 module Stackctl.AWS.Lambda
-  ( LambdaInvokeResult(..)
-  , LambdaError(..)
+  ( LambdaInvokeResult (..)
+  , LambdaError (..)
   , logLambdaInvocationResult
   , isLambdaInvocationSuccess
   , awsLambdaInvoke
@@ -19,36 +19,40 @@ data LambdaInvokeResult
   = LambdaInvokeSuccess ByteString
   | LambdaInvokeError LambdaError (Maybe Text)
   | LambdaInvokeFailure Int (Maybe Text)
-  deriving stock Show
+  deriving stock (Show)
 
 logLambdaInvocationResult :: MonadLogger m => LambdaInvokeResult -> m ()
 logLambdaInvocationResult = \case
   LambdaInvokeSuccess bs -> do
-    let
-      meta = case decode @Value $ BSL.fromStrict bs of
-        Nothing -> ["response" .= decodeUtf8 bs]
-        Just response -> ["response" .= response]
+    let meta = case decode @Value $ BSL.fromStrict bs of
+          Nothing -> ["response" .= decodeUtf8 bs]
+          Just response -> ["response" .= response]
     logInfo $ "LambdaInvokeSuccess" :# meta
   LambdaInvokeError LambdaError {..} mFunctionError ->
-    logError $ (:# []) $ mconcat
-      [ "LambdaInvokeError"
-      , "\n  errorType: " <> errorType
-      , "\n  errorMessage: " <> errorMessage
-      , "\n  trace: "
-      , mconcat $ map ("\n    " <>) trace
-      , "\n  FunctionError: " <> fromMaybe "none" mFunctionError
-      ]
-  LambdaInvokeFailure status mFunctionError -> logError $ (:# []) $ mconcat
-    [ "LambdaInvokeFailure"
-    , "\n  StatusCode: " <> pack (show status)
-    , "\n  FunctionError: " <> fromMaybe "none" mFunctionError
-    ]
+    logError
+      $ (:# [])
+      $ mconcat
+        [ "LambdaInvokeError"
+        , "\n  errorType: " <> errorType
+        , "\n  errorMessage: " <> errorMessage
+        , "\n  trace: "
+        , mconcat $ map ("\n    " <>) trace
+        , "\n  FunctionError: " <> fromMaybe "none" mFunctionError
+        ]
+  LambdaInvokeFailure status mFunctionError ->
+    logError
+      $ (:# [])
+      $ mconcat
+        [ "LambdaInvokeFailure"
+        , "\n  StatusCode: " <> pack (show status)
+        , "\n  FunctionError: " <> fromMaybe "none" mFunctionError
+        ]
 
 isLambdaInvocationSuccess :: LambdaInvokeResult -> Bool
 isLambdaInvocationSuccess = \case
-  LambdaInvokeSuccess{} -> True
-  LambdaInvokeError{} -> False
-  LambdaInvokeFailure{} -> False
+  LambdaInvokeSuccess {} -> True
+  LambdaInvokeError {} -> False
+  LambdaInvokeFailure {} -> False
 
 data LambdaError = LambdaError
   { errorType :: Text
@@ -66,14 +70,20 @@ awsLambdaInvoke
      , ToJSON a
      )
   => Text
-  -> a -- ^ Payload
+  -> a
+  -- ^ Payload
   -> m LambdaInvokeResult
 awsLambdaInvoke name payload = do
   logDebug $ "Invoking function" :# ["name" .= name]
 
   -- Match Lambda's own limit (15 minutes) and add some buffer
-  resp <- awsTimeout 905 $ awsSend $ newInvoke name $ BSL.toStrict $ encode
-    payload
+  resp <-
+    awsTimeout 905
+      $ awsSend
+      $ newInvoke name
+      $ BSL.toStrict
+      $ encode
+        payload
 
   let
     status = resp ^. invokeResponse_statusCode
@@ -89,10 +99,11 @@ awsLambdaInvoke name payload = do
        , "functionError" .= mFunctionError
        ]
 
-  pure $ if
-    | statusIsUnsuccessful status -> LambdaInvokeFailure status mFunctionError
-    | Just e <- mError            -> LambdaInvokeError e mFunctionError
-    | otherwise                   -> LambdaInvokeSuccess response
+  pure
+    $ if
+      | statusIsUnsuccessful status -> LambdaInvokeFailure status mFunctionError
+      | Just e <- mError -> LambdaInvokeError e mFunctionError
+      | otherwise -> LambdaInvokeSuccess response
 
 statusIsUnsuccessful :: Int -> Bool
 statusIsUnsuccessful s = s < 200 || s >= 300
