@@ -8,6 +8,8 @@ import Stackctl.Prelude
 
 import Data.List.Extra (dropPrefix)
 import qualified Data.List.NonEmpty as NE
+import qualified Data.List.NonEmpty.Extra as NE
+import Data.Text.Metrics (levenshtein)
 import Stackctl.AWS
 import Stackctl.AWS.Scope
 import Stackctl.Config (HasConfig)
@@ -64,13 +66,28 @@ discoverSpecs = do
   withThreadContext context $ do
     checkForDuplicateStackNames specPaths
 
-    specs <-
-      sortStackSpecs
-        . filterStackSpecs filterOption
-        <$> traverse (readStackSpec dir) specPaths
+    mAllSpecs <- NE.nonEmpty <$> traverse (readStackSpec dir) specPaths
 
-    when (null specs) $ logWarn "No specs found"
-    specs <$ logDebug ("Discovered specs" :# ["matched" .= length specs])
+    case mAllSpecs of
+      Nothing -> do
+        []
+          <$ logWarn
+            ( "Missing or empty specification directory"
+                :# [ "directory" .= dir
+                   , "hint" .= ("Is this the correct directory?" :: Text)
+                   ]
+            )
+      Just allSpecs -> do
+        let
+          known = stackSpecStackName <$> allSpecs
+          specs =
+            sortStackSpecs
+              $ filterStackSpecs filterOption
+              $ NE.toList allSpecs
+
+        traverse_ (checkForUnknownDepends known) specs
+        when (null specs) $ logWarn "No specs matched filters"
+        specs <$ logDebug ("Discovered specs" :# ["matched" .= length specs])
 
 checkForDuplicateStackNames
   :: (MonadIO m, MonadLogger m) => [StackSpecPath] -> m ()
@@ -94,6 +111,40 @@ checkForDuplicateStackNames =
 
     exitFailure
 
+-- | Warn if a 'StackSpec' depends on a name not in the given 'StackName's
+--
+-- The 'StackName's are built from all specs, but we only run this with specs
+-- that are filtered in.
+--
+-- NB. This function is written so it can easily be made into a fatal error
+-- (like 'checkForDuplicateStackNames'), but we only warn for now.
+checkForUnknownDepends
+  :: MonadLogger m => NonEmpty StackName -> StackSpec -> m ()
+checkForUnknownDepends known spec =
+  traverse_ reportUnknownDepends
+    $ NE.nonEmpty
+    $ filter (`notElem` known)
+    $ stackSpecDepends spec
+ where
+  reportUnknownDepends depends = do
+    for_ depends $ \depend -> do
+      let (nearest, _distance) =
+            NE.minimumBy1 (comparing snd)
+              $ (id &&& getDistance depend)
+              <$> known
+
+      logWarn
+        $ "Stack lists dependency that does not exist"
+        :# [ "dependency"
+              .= ( unStackName (stackSpecStackName spec)
+                    <> " -> "
+                    <> unStackName depend
+                 )
+           , "hint" .= ("Did you mean " <> unStackName nearest <> "?")
+           ]
+
+  getDistance = levenshtein `on` unStackName
+
 buildSpecPath
   :: (MonadReader env m, HasAwsScope env)
   => StackName
